<?php

namespace Drupal\type_tray_icon_display\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field\Plugin\ExtraFieldDisplayBase;
use Drupal\node\Entity\NodeType;

/**
 * Type Tray's icon in a pseudo-field display for viewing content.
 *
 * @ExtraFieldDisplay(
 *   id = "type_tray_icon_display",
 *   label = @Translation("Display Type Tray icon"),
 *   deriver = "Drupal\extra_field_configuration\Plugin\Derivative\ExtraFieldConfigurationDeriver",
 *   visible = true
 * )
 */
class TypeTrayIcon extends ExtraFieldDisplayBase {

  /**
   * {@inheritdoc}
   */
  public function view(ContentEntityInterface $entity) {
    $build = [];

    // @TODO reduce duplication of code between here and our block display
    // src/Plugin/Block/IconBlock::build()

    // For now, Type Tray only applies to nodes.  See the feature request
    // https://www.drupal.org/project/type_tray/issues/3438075
    if ($entity->getEntityTypeId() !== 'node') {
      return;
    }
    /** @var \Drupal\node\NodeInterface $entity */
    $content_type = $entity->getType();

    $content_type_config = NodeType::load($content_type);
    if (isset($content_type_config)) {
      $third_party_property = $content_type_config->get('third_party_settings');
      if (!empty($third_party_property['type_tray']['type_icon'])) {
        $url = $third_party_property['type_tray']['type_icon'];
        $build['icon'] = [
          '#type' => 'component',
          '#component' => 'type_tray_icon_display:icon',
          '#props' => [
            'url' => $url,
            'label' => $content_type_config->label(),
          ],
        ];
      }
    }

    return $build;
  }

}
